@@ -27,7 +27,7 @@ from typing import List, Union
 import gc
 import matplotlib.pyplot as plt
 import numpy as np 
-import cv2
+# import cv2
 
 # Necessary for creating our images.
 from skimage.draw import line_aa
