@@ -5,16 +5,32 @@
 # Deep learning imports.
 import torch
 from torch import nn
+import torch.nn.functional as F
+from torch.utils.data import DataLoader, random_split, TensorDataset
 
 import torchvision
 from torchvision.utils import draw_bounding_boxes, draw_segmentation_masks, make_grid
 from torchvision.ops import masks_to_boxes
 import torchvision.transforms.functional as TF
+from torchvision.models.detection.faster_rcnn import FastRCNNPredictor
+from torchvision.models.detection.mask_rcnn import MaskRCNNPredictor
 
-from torch.utils.data import DataLoader, random_split, TensorDataset
+import pytorch_lightning as pl
+from pytorch_lightning.callbacks import ModelCheckpoint
+from pytorch_lightning.loggers import TensorBoardLogger
 
+import torchmetrics
 from torchmetrics.detection.mean_ap import MeanAveragePrecision
 
+# Standard imports. 
+from typing import List, Union
+import gc
+import matplotlib.pyplot as plt
+import numpy as np 
+# import cv2
+
+# Necessary for creating our images.
+from skimage.draw import line_aa
 
 class DoubleConv(nn.Module):
     """
@@ -240,3 +256,61 @@ class UNET(nn.Module):
         x = self.final_conv(x)
 
         return x
+
+
+def get_fasterrcnn(num_classes = 4, pretrained = True):
+    """A function for loading the PyTorch implimentation of FasterRCNN. 
+    See here for documentation on the input and output specifics: 
+    https://pytorch.org/vision/stable/models/faster_rcnn.html
+
+    Args:
+        num_classes (int): number of output classes desired.
+        pretrained (bool): whether or not to load a model pretrained on the 
+    """
+
+    # load Faster RCNN pre-trained model
+    if pretrained: 
+        model = torchvision.models.detection.fasterrcnn_resnet50_fpn(weights='DEFAULT')
+    else: 
+        model = torchvision.models.detection.fasterrcnn_resnet50_fpn(weights=None)
+    
+    # get the number of input features 
+    in_features = model.roi_heads.box_predictor.cls_score.in_features
+    # define a new head for the detector with required number of classes
+    model.roi_heads.box_predictor = FastRCNNPredictor(in_features, num_classes) 
+
+    return model
+
+
+
+def get_maskrcnn(num_classes = 4, pretrained = True):
+        """A function for loading the PyTorch implimentation of MaskRCNN. 
+    See here for documentation on the input and output specifics: 
+    https://pytorch.org/vision/0.12/generated/torchvision.models.detection.maskrcnn_resnet50_fpn.html
+
+    Args:
+        num_classes (int): number of output classes desired.
+        pretrained (bool): whether or not to load a model pretrained on the 
+    """
+    
+    if pretrained: 
+        model = torchvision.models.detection.maskrcnn_resnet50_fpn(pretrained='DEFAULT')
+    else: 
+        model = torchvision.models.detection.maskrcnn_resnet50_fpn(weights=None)
+
+    # Get number of input features for the classifier.
+    in_features = model.roi_heads.box_predictor.cls_score.in_features
+
+    # Replace the pre-trained box predictor head with a new one.
+    model.roi_heads.box_predictor = FastRCNNPredictor(in_features, num_classes)
+
+    # Now get the number of input features for the mask classifier.
+    in_features_mask = model.roi_heads.mask_predictor.conv5_mask.in_channels
+
+    hidden_layer = 256
+    # Replace the pre-trained mask predictor head with a new one.
+    model.roi_heads.mask_predictor = MaskRCNNPredictor(in_features_mask,
+                                                       hidden_layer,
+                                                       num_classes)
+
+    return model
\ No newline at end of file
