@@ -2,18 +2,42 @@
 # Date: 7/23/22.
 # Description of Module:
 
-# Standard imports.
-import numpy as np
-
 # Deep learning imports.
 import torch
 from torch import nn
+import torch.nn.functional as F
+from torch.utils.data import DataLoader, random_split, TensorDataset
+
+import torchvision
+from torchvision.utils import draw_bounding_boxes, draw_segmentation_masks, make_grid
+from torchvision.ops import masks_to_boxes
+import torchvision.transforms.functional as TF
+from torchvision.models.detection.faster_rcnn import FastRCNNPredictor
+from torchvision.models.detection.mask_rcnn import MaskRCNNPredictor
 
 import pytorch_lightning as pl
+from pytorch_lightning.callbacks import ModelCheckpoint
+from pytorch_lightning.loggers import TensorBoardLogger
+
+import torchmetrics
+from torchmetrics.detection.mean_ap import MeanAveragePrecision
+
+# Standard imports. 
+from typing import List, Union
+import gc
+import matplotlib.pyplot as plt
+import numpy as np 
+# import cv2
+
+# Necessary for creating our images.
+from skimage.draw import line_aa
+import pytorch_lightning as pl
+
+# Local imports
 from intro_to_cv_with_pytorch.cv_datasets import (
     ObjectCounting_DS,
     ImageSegmentation_DS,
-    InstanceSegmentation_DS,
+    ObjectDetection_DS,
 )
 
 
